This is package is aimed to provide several utilities that make my (and hopefully your) life much easier. I shall keep updating it with more features. But, please note, it is an experimental (or a very crude) implementation -- so it is suited to more proficient user or someone who is not affected adversly if anything breaks. It is unlikely that I will be able to entertain pull requests unless very essential to my own work. Hence, I am releasing it under MIT License. Feel free to clone (or download it) and do whatever you want with it.

### Installation Instruction

`pip install pinakinathc_py`

### Usage

```
>>> from pinakinathc_py import SendEmail
>>> client = SendEmail()
Could not find access file.
Welcome to the setup Creator!
Please enter Bot Email: <enter bot email id>
Please enter Bot Password: <enter bot password>
Setup complete.
>>> client.send(<sender email id>, 'hello world!')
```

I won't be able to add a detailed documentation. Hence, if you want to submit a pull request regarding documentation, I will be grateful.

A little advertisement of this author: www.pinakinathc.me
